from setuptools import setup


NAME = 'annotyped'
DESCRIPTION = ''
URL = 'https://gitlab.com/sj1k/typer'
EMAIL = '42Echo6Alpha@gmail.com'
AUTHOR = 'Steven "sj1k" Core'
REQUIRES_PYTHON = '>=3.5.0'
VERSION = '0.1.0'


setup(
    name=NAME,
    description=DESCRIPTION,
    author=AUTHOR,
    email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    version=VERSION,
    packages=['annotyped'],
)
